@@ -24,7 +24,7 @@
 # Written by Peter J Billam, http://www.pjb.com.au
 
 package Crypt::Tea;
-$VERSION = '1.43';
+$VERSION = '1.44';
 
 # Don't like depending on externals; this is strong encrytion ... but ...
 use Exporter; @ISA = qw(Exporter);
@@ -291,7 +291,7 @@ function ascii2bytes(a) { // converts pseudo-base64 to array of bytes
   while (1) { ia++; if (ia>=la) return b; if (a2b[a.charAt(ia)]!=null) break; }
   carry=a2b[a.charAt(ia)];  b[ib] |= carry>>>2; ib++;
   // if low 2 bits of carry are 0 and its the last char, then break
-  carry = 03 & carry;
+  carry = 3 & carry;
   if (carry == 0 && ia == (la-1)) return b;
   b[ib]  = carry<<6;
   while (1) { ia++; if (ia>=la) return b; if (a2b[a.charAt(ia)]!=null) break; }
@@ -305,13 +305,13 @@ function bytes2ascii(b) { // converts array of bytes to pseudo-base64 ascii
  var carry;
  while (1) {   // reads 3 bytes and produces 4 chars
   if (ib >= lb) break;   b1 = 0xFF & b[ib];
-  s += b2a[077 & (b1>>>2)];
-  carry = 03 & b1;
+  s += b2a[63 & (b1>>>2)];
+  carry = 3 & b1;
   ib++;  if (ib >= lb) { s += b2a[carry<<4]; break; }  b2 = 0xFF & b[ib];
   s += b2a[(0xF0 & (carry<<4)) | (b2>>>4)];
   carry = 0xF & b2;
   ib++;  if (ib >= lb) { s += b2a[carry<<2]; break; }  b3 = 0xFF & b[ib];
-  s += b2a[(074 & (carry<<2)) | (b3>>>6)] + b2a[077 & b3];
+  s += b2a[(60 & (carry<<2)) | (b3>>>6)] + b2a[63 & b3];
   ib++;
   if (ib % 36 == 0) s += "\n";
  }
@@ -357,7 +357,7 @@ function pad (bytearray) {
  var newarray = new Array();  var ina = 0;
  var iba = 0; var nba = bytearray.length;
  var npads = 7 - (nba % 8);
- newarray[ina] = (0xF8 & rand_byte()) | (07 & npads); ina++;
+ newarray[ina] = (0xF8 & rand_byte()) | (7 & npads); ina++;
  while (iba < nba) { newarray[ina] = bytearray[iba]; ina++; iba++; }
  var ip = npads; while (ip>0) { newarray[ina] = rand_byte(); ina++; ip--; }
  return newarray;
@@ -460,113 +460,115 @@ function tea_code (v, k) {
  var k0  = k[0]; var k1 = k[1]; var k2 = k[2]; var k3 = k[3];
  var sum = 0; var n = 32;
  while (n-- > 0) {
-  sum += 0x9e3779b9;  // TEA magic number
+  sum -= 1640531527; // TEA magic number 0x9e3779b9 
+  sum = sum|0;  // force it back to 32-bit int
   v0 += ((v1<<4)+k0) ^ (v1+sum) ^ ((v1>>>5)+k1) ;
   v1 += ((v0<<4)+k2) ^ (v0+sum) ^ ((v0>>>5)+k3) ;
  }
- var w = new Array(); w[0] = v0; w[1] = v1; return w;
+ var w = new Array(); w[0] = v0|0; w[1] = v1|0; return w;
 }
 function tea_decode (v, k) {
  // TEA. 2-int (64-bit) cyphertext block in v. 4-int (128-bit) key in k.
  var v0 = v[0]; var v1 = v[1];
  var k0 = k[0]; var k1 = k[1]; var k2 = k[2]; var k3 = k[3];
  var sum = 0; var n = 32;
- sum = 0x9e3779b9 << 5 ;  // TEA magic number
+ sum = -957401312 ; // TEA magic number 0x9e3779b9<<5 
  while (n-- > 0) {
   v1 -= ((v0<<4)+k2) ^ (v0+sum) ^ ((v0>>>5)+k3) ;
   v0 -= ((v1<<4)+k0) ^ (v1+sum) ^ ((v1>>>5)+k1) ;
-  sum -= 0x9e3779b9 ;
+  sum += 1640531527; // TEA magic number 0x9e3779b9 ;
+  sum = sum|0; // force it back to 32-bit int
  }
- var w = new Array(); w[0] = v0; w[1] = v1; return w;
+ var w = new Array(); w[0] = v0|0; w[1] = v1|0; return w;
 }
 
 // ------------- assocarys used by the conversion routines -----------
 c2b = new Object();
-c2b["\000"]=0000; c2b["\001"]=0001; c2b["\002"]=0002; c2b["\003"]=0003;
-c2b["\004"]=0004; c2b["\005"]=0005; c2b["\006"]=0006; c2b["\007"]=0007;
-c2b["\010"]=0010; c2b["\011"]=0011; c2b["\012"]=0012; c2b["\013"]=0013;
-c2b["\014"]=0014; c2b["\015"]=0015; c2b["\016"]=0016; c2b["\017"]=0017;
-c2b["\020"]=0020; c2b["\021"]=0021; c2b["\022"]=0022; c2b["\023"]=0023;
-c2b["\024"]=0024; c2b["\025"]=0025; c2b["\026"]=0026; c2b["\027"]=0027;
-c2b["\030"]=0030; c2b["\031"]=0031; c2b["\032"]=0032; c2b["\033"]=0033;
-c2b["\034"]=0034; c2b["\035"]=0035; c2b["\036"]=0036; c2b["\037"]=0037;
-c2b["\040"]=0040; c2b["\041"]=0041; c2b["\042"]=0042; c2b["\043"]=0043;
-c2b["\044"]=0044; c2b["\045"]=0045; c2b["\046"]=0046; c2b["\047"]=0047;
-c2b["\050"]=0050; c2b["\051"]=0051; c2b["\052"]=0052; c2b["\053"]=0053;
-c2b["\054"]=0054; c2b["\055"]=0055; c2b["\056"]=0056; c2b["\057"]=0057;
-c2b["\060"]=0060; c2b["\061"]=0061; c2b["\062"]=0062; c2b["\063"]=0063;
-c2b["\064"]=0064; c2b["\065"]=0065; c2b["\066"]=0066; c2b["\067"]=0067;
-c2b["\070"]=0070; c2b["\071"]=0071; c2b["\072"]=0072; c2b["\073"]=0073;
-c2b["\074"]=0074; c2b["\075"]=0075; c2b["\076"]=0076; c2b["\077"]=0077;
-c2b["\100"]=0100; c2b["\101"]=0101; c2b["\102"]=0102; c2b["\103"]=0103;
-c2b["\104"]=0104; c2b["\105"]=0105; c2b["\106"]=0106; c2b["\107"]=0107;
-c2b["\110"]=0110; c2b["\111"]=0111; c2b["\112"]=0112; c2b["\113"]=0113;
-c2b["\114"]=0114; c2b["\115"]=0115; c2b["\116"]=0116; c2b["\117"]=0117;
-c2b["\120"]=0120; c2b["\121"]=0121; c2b["\122"]=0122; c2b["\123"]=0123;
-c2b["\124"]=0124; c2b["\125"]=0125; c2b["\126"]=0126; c2b["\127"]=0127;
-c2b["\130"]=0130; c2b["\131"]=0131; c2b["\132"]=0132; c2b["\133"]=0133;
-c2b["\134"]=0134; c2b["\135"]=0135; c2b["\136"]=0136; c2b["\137"]=0137;
-c2b["\140"]=0140; c2b["\141"]=0141; c2b["\142"]=0142; c2b["\143"]=0143;
-c2b["\144"]=0144; c2b["\145"]=0145; c2b["\146"]=0146; c2b["\147"]=0147;
-c2b["\150"]=0150; c2b["\151"]=0151; c2b["\152"]=0152; c2b["\153"]=0153;
-c2b["\154"]=0154; c2b["\155"]=0155; c2b["\156"]=0156; c2b["\157"]=0157;
-c2b["\160"]=0160; c2b["\161"]=0161; c2b["\162"]=0162; c2b["\163"]=0163;
-c2b["\164"]=0164; c2b["\165"]=0165; c2b["\166"]=0166; c2b["\167"]=0167;
-c2b["\170"]=0170; c2b["\171"]=0171; c2b["\172"]=0172; c2b["\173"]=0173;
-c2b["\174"]=0174; c2b["\175"]=0175; c2b["\176"]=0176; c2b["\177"]=0177;
-c2b["\200"]=0200; c2b["\201"]=0201; c2b["\202"]=0202; c2b["\203"]=0203;
-c2b["\204"]=0204; c2b["\205"]=0205; c2b["\206"]=0206; c2b["\207"]=0207;
-c2b["\210"]=0210; c2b["\211"]=0211; c2b["\212"]=0212; c2b["\213"]=0213;
-c2b["\214"]=0214; c2b["\215"]=0215; c2b["\216"]=0216; c2b["\217"]=0217;
-c2b["\220"]=0220; c2b["\221"]=0221; c2b["\222"]=0222; c2b["\223"]=0223;
-c2b["\224"]=0224; c2b["\225"]=0225; c2b["\226"]=0226; c2b["\227"]=0227;
-c2b["\230"]=0230; c2b["\231"]=0231; c2b["\232"]=0232; c2b["\233"]=0233;
-c2b["\234"]=0234; c2b["\235"]=0235; c2b["\236"]=0236; c2b["\237"]=0237;
-c2b["\240"]=0240; c2b["\241"]=0241; c2b["\242"]=0242; c2b["\243"]=0243;
-c2b["\244"]=0244; c2b["\245"]=0245; c2b["\246"]=0246; c2b["\247"]=0247;
-c2b["\250"]=0250; c2b["\251"]=0251; c2b["\252"]=0252; c2b["\253"]=0253;
-c2b["\254"]=0254; c2b["\255"]=0255; c2b["\256"]=0256; c2b["\257"]=0257;
-c2b["\260"]=0260; c2b["\261"]=0261; c2b["\262"]=0262; c2b["\263"]=0263;
-c2b["\264"]=0264; c2b["\265"]=0265; c2b["\266"]=0266; c2b["\267"]=0267;
-c2b["\270"]=0270; c2b["\271"]=0271; c2b["\272"]=0272; c2b["\273"]=0273;
-c2b["\274"]=0274; c2b["\275"]=0275; c2b["\276"]=0276; c2b["\277"]=0277;
-c2b["\300"]=0300; c2b["\301"]=0301; c2b["\302"]=0302; c2b["\303"]=0303;
-c2b["\304"]=0304; c2b["\305"]=0305; c2b["\306"]=0306; c2b["\307"]=0307;
-c2b["\310"]=0310; c2b["\311"]=0311; c2b["\312"]=0312; c2b["\313"]=0313;
-c2b["\314"]=0314; c2b["\315"]=0315; c2b["\316"]=0316; c2b["\317"]=0317;
-c2b["\320"]=0320; c2b["\321"]=0321; c2b["\322"]=0322; c2b["\323"]=0323;
-c2b["\324"]=0324; c2b["\325"]=0325; c2b["\326"]=0326; c2b["\327"]=0327;
-c2b["\330"]=0330; c2b["\331"]=0331; c2b["\332"]=0332; c2b["\333"]=0333;
-c2b["\334"]=0334; c2b["\335"]=0335; c2b["\336"]=0336; c2b["\337"]=0337;
-c2b["\340"]=0340; c2b["\341"]=0341; c2b["\342"]=0342; c2b["\343"]=0343;
-c2b["\344"]=0344; c2b["\345"]=0345; c2b["\346"]=0346; c2b["\347"]=0347;
-c2b["\350"]=0350; c2b["\351"]=0351; c2b["\352"]=0352; c2b["\353"]=0353;
-c2b["\354"]=0354; c2b["\355"]=0355; c2b["\356"]=0356; c2b["\357"]=0357;
-c2b["\360"]=0360; c2b["\361"]=0361; c2b["\362"]=0362; c2b["\363"]=0363;
-c2b["\364"]=0364; c2b["\365"]=0365; c2b["\366"]=0366; c2b["\367"]=0367;
-c2b["\370"]=0370; c2b["\371"]=0371; c2b["\372"]=0372; c2b["\373"]=0373;
-c2b["\374"]=0374; c2b["\375"]=0375; c2b["\376"]=0376; c2b["\377"]=0377;
+c2b["\000"]=0;  c2b["\001"]=1;  c2b["\002"]=2;  c2b["\003"]=3;
+c2b["\004"]=4;  c2b["\005"]=5;  c2b["\006"]=6;  c2b["\007"]=7;
+c2b["\010"]=8;  c2b["\011"]=9;  c2b["\012"]=10; c2b["\013"]=11;
+c2b["\014"]=12; c2b["\015"]=13; c2b["\016"]=14; c2b["\017"]=15;
+c2b["\020"]=16; c2b["\021"]=17; c2b["\022"]=18; c2b["\023"]=19;
+c2b["\024"]=20; c2b["\025"]=21; c2b["\026"]=22; c2b["\027"]=23;
+c2b["\030"]=24; c2b["\031"]=25; c2b["\032"]=26; c2b["\033"]=27;
+c2b["\034"]=28; c2b["\035"]=29; c2b["\036"]=30; c2b["\037"]=31;
+c2b["\040"]=32; c2b["\041"]=33; c2b["\042"]=34; c2b["\043"]=35;
+c2b["\044"]=36; c2b["\045"]=37; c2b["\046"]=38; c2b["\047"]=39;
+c2b["\050"]=40; c2b["\051"]=41; c2b["\052"]=42; c2b["\053"]=43;
+c2b["\054"]=44; c2b["\055"]=45; c2b["\056"]=46; c2b["\057"]=47;
+c2b["\060"]=48; c2b["\061"]=49; c2b["\062"]=50; c2b["\063"]=51;
+c2b["\064"]=52; c2b["\065"]=53; c2b["\066"]=54; c2b["\067"]=55;
+c2b["\070"]=56; c2b["\071"]=57; c2b["\072"]=58; c2b["\073"]=59;
+c2b["\074"]=60; c2b["\075"]=61; c2b["\076"]=62; c2b["\077"]=63;
+c2b["\100"]=64; c2b["\101"]=65; c2b["\102"]=66; c2b["\103"]=67;
+c2b["\104"]=68; c2b["\105"]=69; c2b["\106"]=70; c2b["\107"]=71;
+c2b["\110"]=72; c2b["\111"]=73; c2b["\112"]=74; c2b["\113"]=75;
+c2b["\114"]=76; c2b["\115"]=77; c2b["\116"]=78; c2b["\117"]=79;
+c2b["\120"]=80; c2b["\121"]=81; c2b["\122"]=82; c2b["\123"]=83;
+c2b["\124"]=84; c2b["\125"]=85; c2b["\126"]=86; c2b["\127"]=87;
+c2b["\130"]=88; c2b["\131"]=89; c2b["\132"]=90; c2b["\133"]=91;
+c2b["\134"]=92; c2b["\135"]=93; c2b["\136"]=94; c2b["\137"]=95;
+c2b["\140"]=96; c2b["\141"]=97; c2b["\142"]=98; c2b["\143"]=99;
+c2b["\144"]=100; c2b["\145"]=101; c2b["\146"]=102; c2b["\147"]=103;
+c2b["\150"]=104; c2b["\151"]=105; c2b["\152"]=106; c2b["\153"]=107;
+c2b["\154"]=108; c2b["\155"]=109; c2b["\156"]=110; c2b["\157"]=111;
+c2b["\160"]=112; c2b["\161"]=113; c2b["\162"]=114; c2b["\163"]=115;
+c2b["\164"]=116; c2b["\165"]=117; c2b["\166"]=118; c2b["\167"]=119;
+c2b["\170"]=120; c2b["\171"]=121; c2b["\172"]=122; c2b["\173"]=123;
+c2b["\174"]=124; c2b["\175"]=125; c2b["\176"]=126; c2b["\177"]=127;
+c2b["\200"]=128; c2b["\201"]=129; c2b["\202"]=130; c2b["\203"]=131;
+c2b["\204"]=132; c2b["\205"]=133; c2b["\206"]=134; c2b["\207"]=135;
+c2b["\210"]=136; c2b["\211"]=137; c2b["\212"]=138; c2b["\213"]=139;
+c2b["\214"]=140; c2b["\215"]=141; c2b["\216"]=142; c2b["\217"]=143;
+c2b["\220"]=144; c2b["\221"]=145; c2b["\222"]=146; c2b["\223"]=147;
+c2b["\224"]=148; c2b["\225"]=149; c2b["\226"]=150; c2b["\227"]=151;
+c2b["\230"]=152; c2b["\231"]=153; c2b["\232"]=154; c2b["\233"]=155;
+c2b["\234"]=156; c2b["\235"]=157; c2b["\236"]=158; c2b["\237"]=159;
+c2b["\240"]=160; c2b["\241"]=161; c2b["\242"]=162; c2b["\243"]=163;
+c2b["\244"]=164; c2b["\245"]=165; c2b["\246"]=166; c2b["\247"]=167;
+c2b["\250"]=168; c2b["\251"]=169; c2b["\252"]=170; c2b["\253"]=171;
+c2b["\254"]=172; c2b["\255"]=173; c2b["\256"]=174; c2b["\257"]=175;
+c2b["\260"]=176; c2b["\261"]=177; c2b["\262"]=178; c2b["\263"]=179;
+c2b["\264"]=180; c2b["\265"]=181; c2b["\266"]=182; c2b["\267"]=183;
+c2b["\270"]=184; c2b["\271"]=185; c2b["\272"]=186; c2b["\273"]=187;
+c2b["\274"]=188; c2b["\275"]=189; c2b["\276"]=190; c2b["\277"]=191;
+c2b["\300"]=192; c2b["\301"]=193; c2b["\302"]=194; c2b["\303"]=195;
+c2b["\304"]=196; c2b["\305"]=197; c2b["\306"]=198; c2b["\307"]=199;
+c2b["\310"]=200; c2b["\311"]=201; c2b["\312"]=202; c2b["\313"]=203;
+c2b["\314"]=204; c2b["\315"]=205; c2b["\316"]=206; c2b["\317"]=207;
+c2b["\320"]=208; c2b["\321"]=209; c2b["\322"]=210; c2b["\323"]=211;
+c2b["\324"]=212; c2b["\325"]=213; c2b["\326"]=214; c2b["\327"]=215;
+c2b["\330"]=216; c2b["\331"]=217; c2b["\332"]=218; c2b["\333"]=219;
+c2b["\334"]=220; c2b["\335"]=221; c2b["\336"]=222; c2b["\337"]=223;
+c2b["\340"]=224; c2b["\341"]=225; c2b["\342"]=226; c2b["\343"]=227;
+c2b["\344"]=228; c2b["\345"]=229; c2b["\346"]=230; c2b["\347"]=231;
+c2b["\350"]=232; c2b["\351"]=233; c2b["\352"]=234; c2b["\353"]=235;
+c2b["\354"]=236; c2b["\355"]=237; c2b["\356"]=238; c2b["\357"]=239;
+c2b["\360"]=240; c2b["\361"]=241; c2b["\362"]=242; c2b["\363"]=243;
+c2b["\364"]=244; c2b["\365"]=245; c2b["\366"]=246; c2b["\367"]=247;
+c2b["\370"]=248; c2b["\371"]=249; c2b["\372"]=250; c2b["\373"]=251;
+c2b["\374"]=252; c2b["\375"]=253; c2b["\376"]=254; c2b["\377"]=255;
 b2c = new Object();
 for (b in c2b) { b2c[c2b[b]] = b; }
 
 // ascii to 6-bit bin to ascii
 a2b = new Object();
-a2b["A"]=000; a2b["B"]=001; a2b["C"]=002; a2b["D"]=003;
-a2b["E"]=004; a2b["F"]=005; a2b["G"]=006; a2b["H"]=007;
-a2b["I"]=010; a2b["J"]=011; a2b["K"]=012; a2b["L"]=013;
-a2b["M"]=014; a2b["N"]=015; a2b["O"]=016; a2b["P"]=017;
-a2b["Q"]=020; a2b["R"]=021; a2b["S"]=022; a2b["T"]=023;
-a2b["U"]=024; a2b["V"]=025; a2b["W"]=026; a2b["X"]=027;
-a2b["Y"]=030; a2b["Z"]=031; a2b["a"]=032; a2b["b"]=033;
-a2b["c"]=034; a2b["d"]=035; a2b["e"]=036; a2b["f"]=037;
-a2b["g"]=040; a2b["h"]=041; a2b["i"]=042; a2b["j"]=043;
-a2b["k"]=044; a2b["l"]=045; a2b["m"]=046; a2b["n"]=047;
-a2b["o"]=050; a2b["p"]=051; a2b["q"]=052; a2b["r"]=053;
-a2b["s"]=054; a2b["t"]=055; a2b["u"]=056; a2b["v"]=057;
-a2b["w"]=060; a2b["x"]=061; a2b["y"]=062; a2b["z"]=063;
-a2b["0"]=064; a2b["1"]=065; a2b["2"]=066; a2b["3"]=067;
-a2b["4"]=070; a2b["5"]=071; a2b["6"]=072; a2b["7"]=073;
-a2b["8"]=074; a2b["9"]=075; a2b["+"]=076; a2b["_"]=077;
+a2b["A"]=0;  a2b["B"]=1;  a2b["C"]=2;  a2b["D"]=3;
+a2b["E"]=4;  a2b["F"]=5;  a2b["G"]=6;  a2b["H"]=7;
+a2b["I"]=8;  a2b["J"]=9;  a2b["K"]=10; a2b["L"]=11;
+a2b["M"]=12; a2b["N"]=13; a2b["O"]=14; a2b["P"]=15;
+a2b["Q"]=16; a2b["R"]=17; a2b["S"]=18; a2b["T"]=19;
+a2b["U"]=20; a2b["V"]=21; a2b["W"]=22; a2b["X"]=23;
+a2b["Y"]=24; a2b["Z"]=25; a2b["a"]=26; a2b["b"]=27;
+a2b["c"]=28; a2b["d"]=29; a2b["e"]=30; a2b["f"]=31;
+a2b["g"]=32; a2b["h"]=33; a2b["i"]=34; a2b["j"]=35;
+a2b["k"]=36; a2b["l"]=37; a2b["m"]=38; a2b["n"]=39;
+a2b["o"]=40; a2b["p"]=41; a2b["q"]=42; a2b["r"]=43;
+a2b["s"]=44; a2b["t"]=45; a2b["u"]=46; a2b["v"]=47;
+a2b["w"]=48; a2b["x"]=49; a2b["y"]=50; a2b["z"]=51;
+a2b["0"]=52; a2b["1"]=53; a2b["2"]=54; a2b["3"]=55;
+a2b["4"]=56; a2b["5"]=57; a2b["6"]=58; a2b["7"]=59;
+a2b["8"]=60; a2b["9"]=61; a2b["+"]=62; a2b["_"]=63;
 
 b2a = new Object();
 for (b in a2b) { b2a[a2b[b]] = ''+b; }
@@ -609,7 +611,7 @@ bytes for single encryption.
 As of version 1.34, various Htauth-specific hook routines
 have now been moved out into the I<CGI::Htauth.pm> module.
 
-Version 1.43,
+Version 1.44,
 #COMMENT#
 
 (c) Peter J Billam 1998
